==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/misc/ThrowFinder.h <==
// public class soot.dava.toolkits.base.misc.ThrowFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b39189bcd8174e5f soot_dava_toolkits_base_misc_ThrowFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_misc_ThrowFinder_H_
#define _JC_soot_dava_toolkits_base_misc_ThrowFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_refs	_jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$refs	_jc_soot_dava_toolkits_base_misc_ThrowFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$nonrefs	_jc_soot_dava_toolkits_base_misc_ThrowFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object	_jc_soot_dava_toolkits_base_misc_ThrowFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vmethods	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtable	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$find$11cedd7f6ccd6795(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *);
extern void _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$find__5fOtherMethods$cedb30b6043cbd8a(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_util_HashMap$object *, struct _jc_java_util_HashMap$object *, struct _jc_java_util_HashSet$object *);
extern jboolean _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$handled__5fException$43d612670a989a4e(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_java_util_HashSet$object *, struct _jc_soot_SootClass$object *);
extern jboolean _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$is__5fHandledByRuntime$4bb5a81f1215f0a7(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootClass$object *);
extern void _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$register__5fAreasOfProtection$da7177ac1643c293(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootMethod$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$find$11cedd7f6ccd6795;
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$find__5fOtherMethods$cedb30b6043cbd8a;
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$handled__5fException$43d612670a989a4e;
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$is__5fHandledByRuntime$4bb5a81f1215f0a7;
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$register__5fAreasOfProtection$da7177ac1643c293;

// Static methods
extern struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *_jc_soot_dava_toolkits_base_misc_ThrowFinder$method$v$df2547a1d2b75b65(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vmethods {
	void	(*find$11cedd7f6ccd6795)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *);
	void	(*find__5fOtherMethods$cedb30b6043cbd8a)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_util_HashMap$object *, struct _jc_java_util_HashMap$object *, struct _jc_java_util_HashSet$object *);
	jboolean	(*handled__5fException$43d612670a989a4e)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_java_util_HashSet$object *, struct _jc_soot_SootClass$object *);
	jboolean	(*is__5fHandledByRuntime$4bb5a81f1215f0a7)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootClass$object *);
	void	(*register__5fAreasOfProtection$da7177ac1643c293)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootMethod$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vmethods	soot_dava_toolkits_base_misc_ThrowFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_refs {
	struct _jc_java_util_HashSet$object	*registeredMethods;
	struct _jc_java_util_HashMap$object	*protectionSet;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$refs {
    _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_refs	soot_dava_toolkits_base_misc_ThrowFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_nonrefs	soot_dava_toolkits_base_misc_ThrowFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object {
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype _jc_soot_dava_toolkits_base_misc_ThrowFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_misc_ThrowFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_misc_ThrowFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_misc_ThrowFinder_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/misc/ThrowFinder.h <==
// public class soot.dava.toolkits.base.misc.ThrowFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b39189bcd8174e5f soot_dava_toolkits_base_misc_ThrowFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_misc_ThrowFinder_H_
#define _JC_soot_dava_toolkits_base_misc_ThrowFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_refs	_jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$refs	_jc_soot_dava_toolkits_base_misc_ThrowFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$nonrefs	_jc_soot_dava_toolkits_base_misc_ThrowFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object	_jc_soot_dava_toolkits_base_misc_ThrowFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vmethods	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtable	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$find$11cedd7f6ccd6795(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$find__5fOtherMethods$cedb30b6043cbd8a(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_util_HashMap$object *, struct _jc_java_util_HashMap$object *, struct _jc_java_util_HashSet$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$handled__5fException$43d612670a989a4e(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_java_util_HashSet$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$is__5fHandledByRuntime$4bb5a81f1215f0a7(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_misc_ThrowFinder$method$register__5fAreasOfProtection$da7177ac1643c293(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$find$11cedd7f6ccd6795;
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$find__5fOtherMethods$cedb30b6043cbd8a;
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$handled__5fException$43d612670a989a4e;
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$is__5fHandledByRuntime$4bb5a81f1215f0a7;
extern _jc_method _jc_soot_dava_toolkits_base_misc_ThrowFinder$method_info$register__5fAreasOfProtection$da7177ac1643c293;

// Static methods
extern struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *_jc_soot_dava_toolkits_base_misc_ThrowFinder$method$v$df2547a1d2b75b65(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vmethods {
	void	(*find$11cedd7f6ccd6795)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *) _JC_JCNI_ATTR;
	void	(*find__5fOtherMethods$cedb30b6043cbd8a)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootMethod$object *, struct _jc_java_util_HashMap$object *, struct _jc_java_util_HashMap$object *, struct _jc_java_util_HashSet$object *) _JC_JCNI_ATTR;
	jboolean	(*handled__5fException$43d612670a989a4e)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_java_util_HashSet$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
	jboolean	(*is__5fHandledByRuntime$4bb5a81f1215f0a7)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
	void	(*register__5fAreasOfProtection$da7177ac1643c293)(_jc_env *, struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vmethods	soot_dava_toolkits_base_misc_ThrowFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_refs {
	struct _jc_java_util_HashSet$object	*registeredMethods;
	struct _jc_java_util_HashMap$object	*protectionSet;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$refs {
    _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_refs	soot_dava_toolkits_base_misc_ThrowFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_misc_ThrowFinder$sub_nonrefs	soot_dava_toolkits_base_misc_ThrowFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_misc_ThrowFinder$object {
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_misc_ThrowFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_misc_ThrowFinder$vtype _jc_soot_dava_toolkits_base_misc_ThrowFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_misc_ThrowFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_misc_ThrowFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_misc_ThrowFinder_H_ */
